//
// @description: Example applications for Impact Acquire
// @copyright: Copyright (C) 2018 - 2020 Balluff GmbH
// @authors: APIs and drivers development team at Balluff GmbH
// @initial date: 2018-04-03
//
// Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
// to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
// and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,i
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#include "CommonGUIFunctions.h"

#include "wxIncludePrologue.h"
#include <wx/progdlg.h>
#include "wxIncludeEpilogue.h"

//-----------------------------------------------------------------------------
void RunThreadAndShowProgress( wxThread* pThread, wxProgressDialog* pDlg, unsigned long threadInterval_ms, int maxExecutionTime_ms )
//-----------------------------------------------------------------------------
{
    pThread->Create();
    pThread->Run();
    while( pThread->IsRunning() )
    {
        wxMilliSleep( threadInterval_ms );
        if( pDlg )
        {
            pDlg->Pulse();
        }
    }
    pThread->Wait();
    if( pDlg )
    {
        pDlg->Update( maxExecutionTime_ms );
    }
}

//-----------------------------------------------------------------------------
void UpdateDeviceListWithProgressMessage( wxWindow* pParent, const mvIMPACT::acquire::DeviceManager& devMgr )
//-----------------------------------------------------------------------------
{
    static const int MAX_TIME_MS = 10000;
    wxProgressDialog progressDialog( wxT( "Scanning For Drivers, Interfaces and Devices" ),
                                     wxT( "Scanning for drivers, interfaces and devices...\n\nThis dialog will disappear automatically once this operation completes!" ),
                                     MAX_TIME_MS, // range
                                     pParent,
                                     wxPD_AUTO_HIDE | wxPD_APP_MODAL | wxPD_ELAPSED_TIME );
    UpdateDeviceListThread thread( devMgr );
    RunThreadAndShowProgress( &thread, &progressDialog, 100, MAX_TIME_MS );
}
