/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2018 - 2019 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2018-12-06
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef ContinuousCaptureQtH
#define ContinuousCaptureQtH ContinuousCaptureQtH
//-----------------------------------------------------------------------------
#include <apps/Common/qtIncludePrologue.h>
#include <QtWidgets/QMainWindow>
#include "ui_ContinuousCaptureQt.h"
#include <QCloseEvent>
#include <QThread>
#include <apps/Common/qtIncludeEpilogue.h>

#include "CaptureThread.h"

//-----------------------------------------------------------------------------
class ContinuousCaptureQt : public QMainWindow, public Ui::ContinuousCaptureQt
//-----------------------------------------------------------------------------
{
    Q_OBJECT

public:
    explicit ContinuousCaptureQt( QWidget* parent = 0 );
    ~ContinuousCaptureQt( void );

private:
    CaptureThread* pCaptureThread_;
    ImageCanvas* pImageCanvas_;
    DeviceManager devMgr_;
    QThread* pThread_ ;
    QMutex lock_;
    FunctionInterface* pFI_;
    GenICam::AcquisitionControl* pAC_;

    void cleanUp( Device* pDev = 0 );
    void closeEvent( QCloseEvent* pEvent );
    Device* getDevice( int deviceIndex ) const
    {
        return devMgr_[deviceIndex];
    }
    void populateCombobox( void );

private slots:
    void closeSelectedDevice( void );
    void errorString( QString msg );
    void openSelectedDevice( void );
    void requestReady( void );
    void setExposureTime( int deviceIndex );
    void setupExposureTimeSlider( void );
    void startAcquisition( void );
    void updateStatistics( const QString& statisticalData )
    {
        label_StatusMessage->setText( statisticalData );
    }
    void userSelectedDeviceInComboBox( void );
};
#endif // ContinuousCaptureQtH
