/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2021 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2021-07-30
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef CheckedListCtrlH
#define CheckedListCtrlH CheckedListCtrlH
//-----------------------------------------------------------------------------
#include "icons.h"

#include <apps/Common/wxIncludePrologue.h>
#include <wx/listctrl.h>
#include <wx/imaglist.h>
#include <apps/Common/wxIncludeEpilogue.h>

//-----------------------------------------------------------------------------
class CheckedListCtrl : public wxListCtrl
//-----------------------------------------------------------------------------
{
    DECLARE_EVENT_TABLE()
    wxImageList m_imageList;

public:
    explicit CheckedListCtrl( wxWindow* pParent, wxWindowID id, const wxPoint& pt, const wxSize& sz, long style ) : wxListCtrl( pParent, id, pt, sz, style ), m_imageList( 16, 16, true )
    {
        SetImageList( &m_imageList, wxIMAGE_LIST_SMALL );
        const wxImage checkboxUnchecked( wxBitmap::NewFromPNGData( checkbox_unchecked_png, sizeof( checkbox_unchecked_png ) ).ConvertToImage() );
        m_imageList.Add( checkboxUnchecked.Scale( 16, 16 ) );
        const wxImage checkboxChecked( wxBitmap::NewFromPNGData( checkbox_checked_png, sizeof( checkbox_checked_png ) ).ConvertToImage() );
        m_imageList.Add( checkboxChecked.Scale( 16, 16 ) );
    }

    void OnMouseEvent( wxMouseEvent& event );
    bool IsChecked( long item ) const;
    void SetChecked( long item, bool checked );
};

#endif // CheckedListCtrlH
