/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2007 - 2021 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2007-09-04
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef mvHYPERIONHandlerH
#define mvHYPERIONHandlerH mvHYPERIONHandlerH
//-----------------------------------------------------------------------------
#include "DeviceHandler.h"

//-----------------------------------------------------------------------------
class DeviceHandlerHYPERION : public DeviceHandler
//-----------------------------------------------------------------------------
{
    wxString firmwareUpdateFileName_;
    wxString firmwareUpdateFolder_;
public:
    explicit DeviceHandlerHYPERION( mvIMPACT::acquire::Device* pDev ) : DeviceHandler( pDev ), firmwareUpdateFileName_(), firmwareUpdateFolder_() {}
    static DeviceHandler* Create( mvIMPACT::acquire::Device* pDev )
    {
        return new DeviceHandlerHYPERION( pDev );
    }
    virtual void SetCustomFirmwareFile( const wxString& customFirmwareFile );
    virtual void SetCustomFirmwarePath( const wxString& customFirmwarePath );
    virtual bool SupportsFirmwareUpdate( void ) const
    {
        return true;
    }
    virtual bool SupportsDMABufferSizeUpdate( int* pCurrentDMASize_kB = 0 );
    virtual bool SupportsFirmwareUpdateFromMVU( void ) const
    {
        return false;
    }
    virtual int UpdateFirmware( bool boSilentMode, bool boPersistentUserSets, bool boUseOnlineArchive );
    virtual int UpdatePermanentDMABufferSize( bool boSilentMode );
};

#endif // mvHYPERIONHandlerH
