/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2006 - 2018 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2006-06-26
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef LogOutputConfigurationDlgH
#define LogOutputConfigurationDlgH LogOutputConfigurationDlgH
//-----------------------------------------------------------------------------
#include <apps/Common/wxIncluder.h>
#include "DebugFileParser.h"

//-----------------------------------------------------------------------------
class LogWriterConfigurationDlg : public wxDialog
//-----------------------------------------------------------------------------
{
    LogOutputConfiguration& m_data;
    //-----------------------------------------------------------------------------
    enum
    //-----------------------------------------------------------------------------
    {
        CB_FILE_OUTPUT = 2,
        MAX_OUTPUT_MASK_BIT = 3,
        MAX_LOG_LEVEL = 6
    };
    wxButton*           m_pBtnChooseDir;
    wxButton*           m_pBtnDefault;
    wxButton*           m_pBtnOk;
    wxButton*           m_pBtnCancel;
    wxCheckBox*         m_ppCBOutputDestinations[MAX_OUTPUT_MASK_BIT];
    wxCheckBox*         m_ppCBOutputFlags[MAX_LOG_LEVEL];
    wxCheckBox*         m_pCBClearFile;
    wxCheckBox*         m_pCBBackupPreviousFile;
    wxStaticText*       m_pOutputFileLabel;
    wxTextCtrl*         m_pOutputFileName;
    wxStaticText*       m_pStylesheetLabel;
    wxTextCtrl*         m_pStylesheetName;
    wxComboBox*         m_pCOMFileFormat;
    wxComboBox*         m_pCOMTimestampFormat;
    //-----------------------------------------------------------------------------
    enum TWidgetIDs
    //-----------------------------------------------------------------------------
    {
        widBtnChooseDir = 1,
        widBtnDefault,
        widBtnOk,
        widBtnCancel,
        widCBFileOutput,
        widCOMFileFormat
    };
    void OnBtnChooseDir( wxCommandEvent& );
    void OnBtnDefault( wxCommandEvent& );
    void OnBtnOk( wxCommandEvent& );
    void OnBtnCancel( wxCommandEvent& );
    void OnCBFileOutput( wxCommandEvent& );
    void OnCOMFileFormatTextChanged( wxCommandEvent& e );
    void SetupDlgControls( void );
    void SetupFileControls( void );
public:
    LogWriterConfigurationDlg( wxWindow* pParent, LogOutputConfiguration& data );
    // any class wishing to process wxWidgets events must use this macro
    DECLARE_EVENT_TABLE()
};

void restoreDefaults( LogOutputConfiguration& data );

#endif // LogOutputConfigurationDlgH
