/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2006 - 2022 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2006-06-26
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef LogOutputHandlerH
#define LogOutputHandlerH LogOutputHandlerH
//-----------------------------------------------------------------------------
#include <apps/Common/wxIncluder.h>
#include "DebugFileParser.h"
#include "DeviceListCtrl.h"
#include <mvIMPACT_CPP/mvIMPACT_acquire.h>
#include <set>
#include <string>

//-----------------------------------------------------------------------------
class LogOutputHandlerDlg : public wxDialog
//-----------------------------------------------------------------------------
{
    typedef std::set<std::string> StringSet;

    wxButton*                           m_pBtnOpen;
    wxButton*                           m_pBtnSave;
    LogOutputListCtrl*                  m_pLogListCtrl;
    wxTextCtrl*                         m_pLogWindow;
    mvIMPACT::acquire::DeviceManager&   m_devMgr;
    unsigned int                        m_devMgrLastChangedCounter;
    LogConfigurationVector&             m_debugData;
    wxTimer                             m_logConfigTimer;
    StringSet                           m_missingConfigs;
    //-----------------------------------------------------------------------------
    enum TWidgetIDs
    //-----------------------------------------------------------------------------
    {
        widBtnLoad = 1,
        widBtnSave
    };
    //-----------------------------------------------------------------------------
    enum TTimerEvent
    //-----------------------------------------------------------------------------
    {
        teUpdate
    };
    void        BuildList( void );
    std::string GetAssociatedDevicesString( const std::string& sectionName );
    void        OnBtnLoad( wxCommandEvent& );
    void        OnBtnSave( wxCommandEvent& );
    void        OnTimer( wxTimerEvent& e );
    void        SetupColumn( long index );
    void        UpdateMissingConfigsList( bool boForceRebuild = false );
    void        WriteErrorMessage( const wxString& msg );
    void        WriteLogMessage( const wxString& msg, const wxTextAttr& style = wxTextAttr( GetDefaultTextColour() ) );
public:
    LogOutputHandlerDlg( wxWindow* pParent, mvIMPACT::acquire::DeviceManager& devMgr, LogConfigurationVector& debugData );
    void ConfigureLogger( int index );
    void DeleteItem( int index );
    void DeleteList( void );
    void InsertItem( int index );
    // any class wishing to process wxWidgets events must use this macro
    DECLARE_EVENT_TABLE()
};

#endif // LogOutputHandlerH
