/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2007 - 2013 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2007-09-04
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef ObjectFactoryH
#define ObjectFactoryH ObjectFactoryH
//-----------------------------------------------------------------------------
#include <map>
#include <utility>

//-----------------------------------------------------------------------------
template<class _PRODUCT, typename _IDENTIFIER, typename _CREATOR, typename _PARAM>
class ObjectFactory
//-----------------------------------------------------------------------------
{
protected:
    typedef std::map<_IDENTIFIER, _CREATOR> CallbackMap;
    const CallbackMap& getCallbacks( void ) const
    {
        return callbacks_;
    }
private:
    CallbackMap callbacks_;
public:
    bool Register( const _IDENTIFIER& id, _CREATOR creator )
    {
        return callbacks_.insert( std::make_pair( id, creator ) ).second;
    }
    bool Unregister( const _IDENTIFIER& id )
    {
        return callbacks_.erase( id ) == 1;
    }
    virtual _PRODUCT* CreateObject( const _IDENTIFIER& id, _PARAM param )
    {
        typename CallbackMap::const_iterator it = callbacks_.find( id );
        if( it == callbacks_.end() )
        {
            return 0;
        }
        return ( it->second )( param );
    }
};

#endif // ObjectFactoryH
