/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2009 - 2021 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2009-12-08
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef PackageDescriptionParserH
#define PackageDescriptionParserH PackageDescriptionParserH
//-----------------------------------------------------------------------------
#include <string.h>
#include <Toolkits/expat/include/ExpatImpl.h>
#include <map>
#include <vector>
#include <apps/Common/wxAbstraction.h>

//-----------------------------------------------------------------------------
struct SuitableProductKey
//-----------------------------------------------------------------------------
{
    wxString name_;
    Version revisionMin_;
    Version revisionMax_;
    explicit SuitableProductKey() : name_(), revisionMin_(), revisionMax_() {}
};

//-----------------------------------------------------------------------------
struct ProductUpdateURLs
//-----------------------------------------------------------------------------
{
    wxString productFamily_;
    wxString updateArchiveUrl_;
    wxString releaseNotesUrl_;
    wxString packageDescriptionUrl_;
    wxString timestamp_;
    explicit ProductUpdateURLs() : productFamily_(), updateArchiveUrl_(), releaseNotesUrl_(), packageDescriptionUrl_(), timestamp_() {}
};

//-----------------------------------------------------------------------------
struct FileEntry
//-----------------------------------------------------------------------------
{
    wxString name_;
    wxString type_;
    wxString description_;
    Version version_;
    Version packageDescriptionVersion_;
    std::map<wxString, SuitableProductKey> suitableProductKeys_;
    wxString localMVUFileName_;
    bool boFromOnline_;
    ProductUpdateURLs onlineUpdateInfos_;
    explicit FileEntry() : name_(), type_(), description_(), version_(), packageDescriptionVersion_(), suitableProductKeys_(), localMVUFileName_(), boFromOnline_( false ), onlineUpdateInfos_() {}
};

typedef std::vector<FileEntry> FileEntryContainer;
typedef std::map<std::string, FileEntry> ProductToFileEntryMap;

//-----------------------------------------------------------------------------
class PackageDescriptionFileParser : public CExpatImpl
//-----------------------------------------------------------------------------
{
    // internal types
    enum TTagType
    {
        ttInvalid,
        ttPackageDescription,
        ttFile,
        ttSuitableProductKey
    };
    static const std::string    m_ATTR_NAME;
    static const std::string    m_ATTR_TYPE;
    static const std::string    m_ATTR_DESCRIPTION;
    static const std::string    m_ATTR_VERSION;
    static const std::string    m_ATTR_REVISION_MIN;
    static const std::string    m_ATTR_REVISION_MAX;

    wxString                    m_lastError;
    FileEntryContainer          m_results;
    Version                     m_packageDescriptionVersion;

    TTagType                    GetTagType( const char* tagName ) const;
public:
    void                        OnPostCreate( void );
    void                        OnStartElement( const XML_Char* pszName, const XML_Char** papszAttrs );
    const wxString&             GetLastError( void ) const
    {
        return m_lastError;
    }
    const FileEntryContainer&   GetResults( void ) const
    {
        return m_results;
    }
};

#endif // PackageDescriptionParserH
