/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2019 - 2021 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2019-01-17
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef ValuesFromUserDlgH
#define ValuesFromUserDlgH ValuesFromUserDlgH
//-----------------------------------------------------------------------------
#include <mvIMPACT_CPP/mvIMPACT_acquire.h>
#include <mvIMPACT_CPP/mvIMPACT_acquire_GenICam.h>
#include "DeviceConfigureFrame.h"

#include <apps/Common/wxIncludePrologue.h>
#include <wx/wx.h>
#include <apps/Common/wxIncludeEpilogue.h>

class DeviceConfigureFrame;
class PropData;
class CheckedListCtrl;
class wxWebView;

typedef std::map<wxString, wxString> StringToStringMap;

//-----------------------------------------------------------------------------
class OkAndCancelDlg : public wxDialog
//-----------------------------------------------------------------------------
{
    DECLARE_EVENT_TABLE()
protected:
    wxButton*                   pBtnApply_;
    wxButton*                   pBtnCancel_;
    wxButton*                   pBtnOk_;

    virtual void OnBtnApply( wxCommandEvent& ) {}
    virtual void OnBtnCancel( wxCommandEvent& )
    {
        EndModal( wxID_CANCEL );
    }
    virtual void OnBtnOk( wxCommandEvent& )
    {
        EndModal( wxID_OK );
    }
    void AddButtons( wxWindow* pWindow, wxSizer* pSizer, bool boCreateApplyButton = false );
    void FinalizeDlgCreation( wxWindow* pWindow, wxSizer* pSizer );
    //-----------------------------------------------------------------------------
    enum TWidgetIDs
    //-----------------------------------------------------------------------------
    {
        widBtnOk = 1,
        widBtnCancel = 2,
        widBtnApply = 3,
        widCheckedListCtrlFWPackage = 4,
        widDownloadSAelectedFWPackages = 5,
        widFirst = 100
    };
public:
    explicit OkAndCancelDlg( wxWindow* pParent, wxWindowID id, const wxString& title, const wxPoint& pos = wxDefaultPosition, const wxSize& size = wxDefaultSize, long style = wxDEFAULT_DIALOG_STYLE, const wxString& name = wxT( "OkAndCancelDlg" ) );
};

//-----------------------------------------------------------------------------
class UpdatesInformationDlg : public OkAndCancelDlg
//-----------------------------------------------------------------------------
{
    DECLARE_EVENT_TABLE()

    wxBoxSizer* pTopDownSizer_;
    wxCheckBox* pCBAutoCheckForOnlineUpdatesWeekly_;
    CheckedListCtrl* pFirmwarePackageList_;
    wxButton* pBtnDownloadSelected_;
    wxWebView* pWhatsNewWebView_;
    DeviceConfigureFrame* pParent_;

    const std::vector<DeviceConfigureFrame::UpdateableDevices>& updateableDevicesContainer_;

    typedef std::map<wxString, ProductUpdateURLs> DeviceFamilyUpdateURLMap;
    DeviceFamilyUpdateURLMap deviceFamilyUpdateURLs_;

    //-----------------------------------------------------------------------------
    enum TFirmwareListColumn
    //-----------------------------------------------------------------------------
    {
        flcMarkForDownload,
        flcDeviceType,
        flcDeviceSerial,
        flcLocalFirmwareVersion,
        flcOnlineFirmwareVersion,
        flcDateReleased,
        flcReleaseNotes
    };

    void OnBtnDownloadSelectedFWPackagesClicked( wxCommandEvent& )
    {
        DownloadSelectedFWPackages();
    }
    void BuildList( void );
    void DownloadSelectedFWPackages( void );
    void HandleListCtrlIndexChange( void );
    void OnSelectedIndexChanged( wxListEvent& )
    {
        HandleListCtrlIndexChange();
    }
    virtual void OnClose( wxCloseEvent& )
    {
        EndModal( wxID_CANCEL );
    }
    typedef DeviceConfigureFrame::UpdateableDevicesContainer UpdateableDevicesContainer;
public:
    explicit UpdatesInformationDlg( DeviceConfigureFrame* pParent, const wxString& title, const UpdateableDevicesContainer& updateableDevicesContainer, const bool boCurrentAutoUpdateCheckState );
    bool IsWeeklyAutoCheckForOnlineUpdatesActive( void ) const
    {
        return pCBAutoCheckForOnlineUpdatesWeekly_->GetValue();
    }
};

#endif // ValuesFromUserDlgH
