/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2008 - 2022 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2008-08-12
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef AssignIPDlgH
#define AssignIPDlgH AssignIPDlgH
//-----------------------------------------------------------------------------
#include <apps/Common/wxIncluder.h>
#include "CustomValidators.h"
#include "TLILibImports.h"

class wxButton;
class wxComboBox;
class wxTextCtrl;
class IPConfigureFrame;

//-----------------------------------------------------------------------------
class AssignIPDlg : public wxDialog
//-----------------------------------------------------------------------------
{
    wxTextCtrl* pTCDeviceMACAddress_;
    wxTextCtrl* pTCDesiredIPAddress_;
    wxTextCtrl* pTCDesiredSubnetMask_;
    wxTextCtrl* pTCDesiredGateway_;
    wxButton* pBtnBuildMACAddress_;
    wxButton* pBtnExecute_;
    wxComboBox* pCBAdapterList_;
    IPConfigureFrame* pParent_;
    //-----------------------------------------------------------------------------
    enum TWidgetIDs
    //-----------------------------------------------------------------------------
    {
        widBtnExecute = wxID_HIGHEST + 1,
        widTCMACAddress,
        widDesiredIPAddress,
        widBtnBuildMACAddress,
        widDesiredSubnetMask,
        widDesiredGateway,
        widAdapterList
    };
    IPv4StringValidator IPv4StringValidator_;
    MACStringValidator MACStringValidator_;
    void OnBtnExecute( wxCommandEvent& );
    void OnBtnBuildMACAddress( wxCommandEvent& );
    void OnDesiredIPAddressChanged( wxCommandEvent& );
public:
    AssignIPDlg( IPConfigureFrame* pParent, const wxString& deviceMACAddress = wxEmptyString, const wxString& connectedIPAddress = wxEmptyString, bool boShowDifferentSubnetWarning = false, bool buildMACFromSerialEnabled = true );
    // any class wishing to process wxWidgets events must use this macro
    DECLARE_EVENT_TABLE()
};

bool ValidateIPDataSet( const wxString& IPAddress, const wxString& SubnetMask, const wxString& Gateway, IPConfigureFrame* pMainFrame, bool boSuppressMismatchWarning );

#endif // AssignIPDlgH
