/*
 * @description: Example applications for Impact Acquire
 * @copyright: Copyright (C) 2021 - 2023 Balluff GmbH
 * @authors: APIs and drivers development team at Balluff GmbH
 * @initial date: 2021-03-29
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice (including the next paragraph) shall be included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
 * WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

//-----------------------------------------------------------------------------
#ifndef SetupUnicastDlgH
#define SetupUnicastDlgH SetupUnicastDlgH
//-----------------------------------------------------------------------------
#include <apps/Common/wxIncluder.h>
#include <map>
#include <mvIMPACT_CPP/mvIMPACT_acquire.h>
#include <mvIMPACT_CPP/mvIMPACT_acquire_GenICam.h>

class wxButton;
class wxComboBox;
class wxGrid;
class wxGridEvent;
class wxTextCtrl;
class IPConfigureFrame;

//-----------------------------------------------------------------------------
class SetupUnicastDlg : public wxDialog
//-----------------------------------------------------------------------------
{
    // any class wishing to process wxWidgets events must use this macro
    DECLARE_EVENT_TABLE()

    wxButton* pBtnAbort_;
    wxButton* pBtnApply_;
    wxButton* pBtnClear_;
    wxButton* pBtnDiscover_;
    wxComboBox* pCBAdapterList_;
    wxGrid* pGridUnicastIPs_;
    IPConfigureFrame* pParent_;

    IPv4StringValidator iPv4StringValidator_;

    int maxUnicastDestinationCount_;

    mvIMPACT::acquire::DeviceManager devMgr_;

    typedef std::vector<mvIMPACT::acquire::GenICam::InterfaceModule*> InterfaceModuleContainer;
    InterfaceModuleContainer validInterfaces_;

    typedef std::map<wxString, std::vector<unsigned int> > UnicastDestinationData;
    UnicastDestinationData unicastDestinationData_;
    UnicastDestinationData initialUnicastDestinationData_;
    //-----------------------------------------------------------------------------
    enum TWidgetIDs
    //-----------------------------------------------------------------------------
    {
        widBtnExecute = wxID_HIGHEST + 1,
        widAdapterList,
        widUnicastCount,
        widBtnAbort,
        widBtnApply,
        widBtnClear,
        widBtnDiscover,
        widGridIPs
    };

    //-----------------------------------------------------------------------------
    enum TGridColors
    //-----------------------------------------------------------------------------
    {
        tgrWhite,
        tgrGreen,
        tgrRed,
        tgrGrey,
        tgrDarkGrey
    };

    void ChangeCellReadWriteAccess( void ) const;
    void EnumerateInterfaces( void );
    wxString GetIPv4AddressAsString( unsigned int ip ) const
    {
        unsigned char bytes[4];
        bytes[0] = ip & 0xFF;
        bytes[1] = ( ip >> 8 ) & 0xFF;
        bytes[2] = ( ip >> 16 ) & 0xFF;
        bytes[3] = ( ip >> 24 ) & 0xFF;
        return wxString::Format( "%d.%d.%d.%d", bytes[3], bytes[2], bytes[1], bytes[0] );
    }

    mvIMPACT::acquire::GenICam::InterfaceModule* GetInterfaceModule( const wxString& identifier ) const;
    void CollectCompatibleGEVInterfaces( void );
    void ColorizeRow( int row, TGridColors color ) const;
    void OnBtnAbort( wxCommandEvent& );
    void OnBtnApply( wxCommandEvent& );
    void OnBtnClear( wxCommandEvent& );
    void OnBtnDiscover( wxCommandEvent& );
    void OnClose( wxCloseEvent& e );
    void OnComboboxInterfaceChanged( wxCommandEvent& );
    void OnGridIPAddressChanged( wxGridEvent& );
    wxString ReadGridData( void );
    void UpdateGrid( void );
    bool ValidateIPv4Address( const wxString& ipv4String );
    void WriteUnicastDataEntrys( const wxString& selectedInterface ) const;
    wxString GetInterfaceIdentifier( unsigned int index ) const;
public:
    SetupUnicastDlg( IPConfigureFrame* pParent );
};

#endif // SetupUnicastDlgH
