#ifndef __PAGE_LIST_POOL_H__
#define __PAGE_LIST_POOL_H__

/*
 * mvPCIe DMA Driver for BVS CA-BN (mvBlueNAOS) series cameras
 *
 * SPDX-FileCopyrightText: 2019 - 2023 MATRIX VISION GmbH <info@matrix-vision.de>
 * SPDX-FileCopyrightText: 2023 Balluff GmbH
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 2 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#ifdef __KERNEL__

struct mvdma_device;            /* forward definition */

/* ******************************************************************************** */
#define MAX_POOL_BLOCKS MVDMA_PAGE_LIST_CNT /* 64, max = 2048 */
#define PAGES_PER_BLOCK (MAX_PAGE_LIST_SIZE_IN_KB / 4)
#define ENTRIES_PER_PAGE (PAGE_SIZE / sizeof(uint64_t))
#define PAGES_IN_POOL (MAX_POOL_BLOCKS * PAGES_PER_BLOCK)

struct page_list_req {
    uint32_t handle;            /* output: a unique ID representing which pages are being used by this request. */
    uint16_t num_pages;         /* input:  the num of 4k pages required - we know this from the scatter-gather functions. Max. of 512 (x0200) allowed. */
    void *addr;                 /* output: the virtual address where the first 8 Byte pointer should be written. Set to NULL on input. */
    dma_addr_t dma_addr;        /* output: the IOMMU address of 'addr'. All DMA mapping/unmapping is handled within the page list pool. */
};

/* *********************************************************************************************** */
int init_page_list_pool(struct mvdma_device *pdma);
int reserve_page_list(struct mvdma_device *pdma, struct page_list_req *plr);
int free_page_list(struct mvdma_device *pdma, struct page_list_req *plr);
int clear_page_list_pool(struct mvdma_device *pdma);
int free_page_list_pool(struct mvdma_device *pdma);

#endif /* __KERNEL__ */
#endif /* __PAGE_LIST_POOL_H__ */
